@@ -1,7 +1,6 @@
 from collections import deque
 from itertools import (accumulate,
                        chain,
-                       groupby,
                        repeat)
 from typing import (FrozenSet,
                     Iterable,
@@ -12,7 +11,6 @@ from typing import (FrozenSet,
 
 from decision.partition import coin_change
 from reprit.base import generate_repr
-from robust import parallelogram
 from robust.angular import (Orientation,
                             orientation)
 from robust.linear import (SegmentsRelationship,
@@ -31,25 +29,12 @@ from .quad_edge import (QuadEdge,
                         edges_with_opposites)
 from .utils import (ceil_log2,
                     contour_to_segments,
-                    flatten,
                     normalize_contour,
                     pairwise,
                     to_clockwise_contour,
-                    to_min_max,
                     to_unique_objects)
 
 
-class CollinearFragmentsKey:
-    __slots__ = 'edge',
-
-    def __init__(self, edge: QuadEdge) -> None:
-        self.edge = edge
-
-    def __eq__(self, other: 'CollinearFragmentsKey') -> bool:
-        return not parallelogram.signed_area(self.edge.start, self.edge.end,
-                                             other.edge.start, other.edge.end)
-
-
 class Triangulation:
     __slots__ = 'left_edge', 'right_edge', '_triangular_holes_vertices'
 
@@ -93,31 +78,16 @@ class Triangulation:
 
     def bound(self, border_segments: Sequence[Segment]) -> None:
         border_endpoints = {frozenset(segment) for segment in border_segments}
-
-        def unite_fragments(fragments: Iterable[QuadEdge]) -> Segment:
-            return to_min_max(flatten(fragment.segment
-                                      for fragment in fragments))
-
-        non_boundary = set(flatten(
-                edges_with_opposites(fragment
-                                     for fragment in fragments
-                                     if (fragment.endpoints
-                                         not in border_endpoints))
-                for fragments in (
-                    tuple(fragments)
-                    for _, fragments in groupby(self.unique_boundary_edges(),
-                                                key=CollinearFragmentsKey))
-                if (frozenset(unite_fragments(fragments))
-                    not in border_endpoints)))
+        non_boundary = {edge
+                        for edge in self.unique_boundary_edges()
+                        if edge.endpoints not in border_endpoints}
         while non_boundary:
             edge = non_boundary.pop()
-            non_boundary.remove(edge.opposite)
             candidates = edge_to_neighbours(edge)
             self.delete(edge)
-            non_boundary.update(edges_with_opposites(
-                    candidate
-                    for candidate in candidates
-                    if candidate.endpoints not in border_endpoints))
+            non_boundary.update(candidate
+                                for candidate in candidates
+                                if candidate.endpoints not in border_endpoints)
 
     def cut(self, holes: Sequence[Contour]) -> None:
         if not holes:
